import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The ``AWS::ApiGatewayV2::DomainName`` resource specifies a custom domain name for your API in Amazon API Gateway (API Gateway).
 *  You can use a custom domain name to provide a URL that's more intuitive and easier to recall. For more information about using custom domain names, see [Set up Custom Domain Name for an API in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/how-to-custom-domains.html) in the *API Gateway Developer Guide*.
 */
export declare class DomainName extends pulumi.CustomResource {
    /**
     * Get an existing DomainName resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DomainName;
    /**
     * Returns true if the given object is an instance of DomainName.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DomainName;
    /**
     * The custom domain name for your API in Amazon API Gateway. Uppercase letters and the underscore (``_``) character are not supported.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * Represents an Amazon Resource Name (ARN).
     */
    readonly domainNameArn: pulumi.Output<string>;
    /**
     * The domain name configurations.
     */
    readonly domainNameConfigurations: pulumi.Output<outputs.apigatewayv2.DomainNameConfiguration[] | undefined>;
    /**
     * The mutual TLS authentication configuration for a custom domain name.
     */
    readonly mutualTlsAuthentication: pulumi.Output<outputs.apigatewayv2.DomainNameMutualTlsAuthentication | undefined>;
    /**
     * The domain name associated with the regional endpoint for this custom domain name. You set up this association by adding a DNS record that points the custom domain name to this regional domain name.
     */
    readonly regionalDomainName: pulumi.Output<string>;
    /**
     * The region-specific Amazon Route 53 Hosted Zone ID of the regional endpoint.
     */
    readonly regionalHostedZoneId: pulumi.Output<string>;
    /**
     * The routing mode API Gateway uses to route traffic to your APIs.
     */
    readonly routingMode: pulumi.Output<enums.apigatewayv2.DomainNameRoutingMode | undefined>;
    /**
     * The collection of tags associated with a domain name.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a DomainName resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DomainNameArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DomainName resource.
 */
export interface DomainNameArgs {
    /**
     * The custom domain name for your API in Amazon API Gateway. Uppercase letters and the underscore (``_``) character are not supported.
     */
    domainName: pulumi.Input<string>;
    /**
     * The domain name configurations.
     */
    domainNameConfigurations?: pulumi.Input<pulumi.Input<inputs.apigatewayv2.DomainNameConfigurationArgs>[]>;
    /**
     * The mutual TLS authentication configuration for a custom domain name.
     */
    mutualTlsAuthentication?: pulumi.Input<inputs.apigatewayv2.DomainNameMutualTlsAuthenticationArgs>;
    /**
     * The routing mode API Gateway uses to route traffic to your APIs.
     */
    routingMode?: pulumi.Input<enums.apigatewayv2.DomainNameRoutingMode>;
    /**
     * The collection of tags associated with a domain name.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
