import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * AWS Cost Anomaly Detection leverages advanced Machine Learning technologies to identify anomalous spend and root causes, so you can quickly take action. Create subscription to be notified
 */
export declare function getAnomalySubscription(args: GetAnomalySubscriptionArgs, opts?: pulumi.InvokeOptions): Promise<GetAnomalySubscriptionResult>;
export interface GetAnomalySubscriptionArgs {
    /**
     * The `AnomalySubscription` Amazon Resource Name (ARN).
     */
    subscriptionArn: string;
}
export interface GetAnomalySubscriptionResult {
    /**
     * The accountId
     */
    readonly accountId?: string;
    /**
     * The frequency at which anomaly reports are sent over email.
     */
    readonly frequency?: enums.ce.AnomalySubscriptionFrequency;
    /**
     * A list of cost anomaly monitors.
     */
    readonly monitorArnList?: string[];
    /**
     * A list of subscriber
     */
    readonly subscribers?: outputs.ce.AnomalySubscriptionSubscriber[];
    /**
     * The `AnomalySubscription` Amazon Resource Name (ARN).
     */
    readonly subscriptionArn?: string;
    /**
     * The name of the subscription.
     */
    readonly subscriptionName?: string;
    /**
     * The dollar value that triggers a notification if the threshold is exceeded.
     */
    readonly threshold?: number;
    /**
     * An Expression object in JSON String format used to specify the anomalies that you want to generate alerts for.
     */
    readonly thresholdExpression?: string;
}
/**
 * AWS Cost Anomaly Detection leverages advanced Machine Learning technologies to identify anomalous spend and root causes, so you can quickly take action. Create subscription to be notified
 */
export declare function getAnomalySubscriptionOutput(args: GetAnomalySubscriptionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAnomalySubscriptionResult>;
export interface GetAnomalySubscriptionOutputArgs {
    /**
     * The `AnomalySubscription` Amazon Resource Name (ARN).
     */
    subscriptionArn: pulumi.Input<string>;
}
