import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents an AWS account that is a part of a collaboration
 */
export declare class Membership extends pulumi.CustomResource {
    /**
     * Get an existing Membership resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Membership;
    /**
     * Returns true if the given object is an instance of Membership.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Membership;
    /**
     * Returns the Amazon Resource Name (ARN) of the specified membership.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:membership/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Returns the Amazon Resource Name (ARN) of the specified collaboration.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:collaboration/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly collaborationArn: pulumi.Output<string>;
    /**
     * Returns the unique identifier of the specified collaboration creator account.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly collaborationCreatorAccountId: pulumi.Output<string>;
    /**
     * The unique ID for the associated collaboration.
     */
    readonly collaborationIdentifier: pulumi.Output<string>;
    /**
     * The default job result configuration for the membership.
     */
    readonly defaultJobResultConfiguration: pulumi.Output<outputs.cleanrooms.MembershipProtectedJobResultConfiguration | undefined>;
    /**
     * The default protected query result configuration as specified by the member who can receive results.
     */
    readonly defaultResultConfiguration: pulumi.Output<outputs.cleanrooms.MembershipProtectedQueryResultConfiguration | undefined>;
    /**
     * An indicator as to whether job logging has been enabled or disabled for the collaboration.
     *
     * When `ENABLED` , AWS Clean Rooms logs details about jobs run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is `DISABLED` .
     */
    readonly jobLogStatus: pulumi.Output<enums.cleanrooms.MembershipJobLogStatus | undefined>;
    /**
     * Returns the unique identifier of the specified membership.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE22222`
     */
    readonly membershipIdentifier: pulumi.Output<string>;
    /**
     * The payment responsibilities accepted by the collaboration member.
     */
    readonly paymentConfiguration: pulumi.Output<outputs.cleanrooms.MembershipPaymentConfiguration | undefined>;
    /**
     * An indicator as to whether query logging has been enabled or disabled for the membership.
     *
     * When `ENABLED` , AWS Clean Rooms logs details about queries run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is `DISABLED` .
     */
    readonly queryLogStatus: pulumi.Output<enums.cleanrooms.MembershipQueryLogStatus>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms membership.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Membership resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MembershipArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Membership resource.
 */
export interface MembershipArgs {
    /**
     * The unique ID for the associated collaboration.
     */
    collaborationIdentifier: pulumi.Input<string>;
    /**
     * The default job result configuration for the membership.
     */
    defaultJobResultConfiguration?: pulumi.Input<inputs.cleanrooms.MembershipProtectedJobResultConfigurationArgs>;
    /**
     * The default protected query result configuration as specified by the member who can receive results.
     */
    defaultResultConfiguration?: pulumi.Input<inputs.cleanrooms.MembershipProtectedQueryResultConfigurationArgs>;
    /**
     * An indicator as to whether job logging has been enabled or disabled for the collaboration.
     *
     * When `ENABLED` , AWS Clean Rooms logs details about jobs run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is `DISABLED` .
     */
    jobLogStatus?: pulumi.Input<enums.cleanrooms.MembershipJobLogStatus>;
    /**
     * The payment responsibilities accepted by the collaboration member.
     */
    paymentConfiguration?: pulumi.Input<inputs.cleanrooms.MembershipPaymentConfigurationArgs>;
    /**
     * An indicator as to whether query logging has been enabled or disabled for the membership.
     *
     * When `ENABLED` , AWS Clean Rooms logs details about queries run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is `DISABLED` .
     */
    queryLogStatus: pulumi.Input<enums.cleanrooms.MembershipQueryLogStatus>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms membership.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
