import * as pulumi from "@pulumi/pulumi";
/**
 * The default version of a resource that has been registered in the CloudFormation Registry.
 */
export declare class ResourceDefaultVersion extends pulumi.CustomResource {
    /**
     * Get an existing ResourceDefaultVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResourceDefaultVersion;
    /**
     * Returns true if the given object is an instance of ResourceDefaultVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResourceDefaultVersion;
    /**
     * The Amazon Resource Name (ARN) of the type. This is used to uniquely identify a ResourceDefaultVersion
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the type being registered.
     *
     * We recommend that type names adhere to the following pattern: company_or_organization::service::type.
     */
    readonly typeName: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the type version.
     */
    readonly typeVersionArn: pulumi.Output<string | undefined>;
    /**
     * The ID of an existing version of the resource to set as the default.
     */
    readonly versionId: pulumi.Output<string | undefined>;
    /**
     * Create a ResourceDefaultVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ResourceDefaultVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResourceDefaultVersion resource.
 */
export interface ResourceDefaultVersionArgs {
    /**
     * The name of the type being registered.
     *
     * We recommend that type names adhere to the following pattern: company_or_organization::service::type.
     */
    typeName?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the type version.
     */
    typeVersionArn?: pulumi.Input<string>;
    /**
     * The ID of an existing version of the resource to set as the default.
     */
    versionId?: pulumi.Input<string>;
}
