import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Cognito::UserPoolRiskConfigurationAttachment
 */
export declare function getUserPoolRiskConfigurationAttachment(args: GetUserPoolRiskConfigurationAttachmentArgs, opts?: pulumi.InvokeOptions): Promise<GetUserPoolRiskConfigurationAttachmentResult>;
export interface GetUserPoolRiskConfigurationAttachmentArgs {
    /**
     * The app client where this configuration is applied. When this parameter isn't present, the risk configuration applies to all user pool app clients that don't have client-level settings.
     */
    clientId: string;
    /**
     * The ID of the user pool that has the risk configuration applied.
     */
    userPoolId: string;
}
export interface GetUserPoolRiskConfigurationAttachmentResult {
    /**
     * The settings for automated responses and notification templates for adaptive authentication with threat protection.
     */
    readonly accountTakeoverRiskConfiguration?: outputs.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverRiskConfigurationType;
    /**
     * Settings for compromised-credentials actions and authentication types with threat protection in full-function `ENFORCED` mode.
     */
    readonly compromisedCredentialsRiskConfiguration?: outputs.cognito.UserPoolRiskConfigurationAttachmentCompromisedCredentialsRiskConfigurationType;
    /**
     * Exceptions to the risk evaluation configuration, including always-allow and always-block IP address ranges.
     */
    readonly riskExceptionConfiguration?: outputs.cognito.UserPoolRiskConfigurationAttachmentRiskExceptionConfigurationType;
}
/**
 * Resource Type definition for AWS::Cognito::UserPoolRiskConfigurationAttachment
 */
export declare function getUserPoolRiskConfigurationAttachmentOutput(args: GetUserPoolRiskConfigurationAttachmentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserPoolRiskConfigurationAttachmentResult>;
export interface GetUserPoolRiskConfigurationAttachmentOutputArgs {
    /**
     * The app client where this configuration is applied. When this parameter isn't present, the risk configuration applies to all user pool app clients that don't have client-level settings.
     */
    clientId: pulumi.Input<string>;
    /**
     * The ID of the user pool that has the risk configuration applied.
     */
    userPoolId: pulumi.Input<string>;
}
