import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Cognito::IdentityPoolPrincipalTag
 */
export declare class IdentityPoolPrincipalTag extends pulumi.CustomResource {
    /**
     * Get an existing IdentityPoolPrincipalTag resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IdentityPoolPrincipalTag;
    /**
     * Returns true if the given object is an instance of IdentityPoolPrincipalTag.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdentityPoolPrincipalTag;
    /**
     * The identity pool that you want to associate with this principal tag map.
     */
    readonly identityPoolId: pulumi.Output<string>;
    /**
     * The identity pool identity provider (IdP) that you want to associate with this principal tag map.
     */
    readonly identityProviderName: pulumi.Output<string>;
    /**
     * A JSON-formatted list of user claims and the principal tags that you want to associate with them. When Amazon Cognito requests credentials, it sets the value of the principal tag to the value of the user's claim.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Cognito::IdentityPoolPrincipalTag` for more information about the expected schema for this property.
     */
    readonly principalTags: pulumi.Output<any | undefined>;
    /**
     * Use a default set of mappings between claims and tags for this provider, instead of a custom map.
     */
    readonly useDefaults: pulumi.Output<boolean | undefined>;
    /**
     * Create a IdentityPoolPrincipalTag resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdentityPoolPrincipalTagArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IdentityPoolPrincipalTag resource.
 */
export interface IdentityPoolPrincipalTagArgs {
    /**
     * The identity pool that you want to associate with this principal tag map.
     */
    identityPoolId: pulumi.Input<string>;
    /**
     * The identity pool identity provider (IdP) that you want to associate with this principal tag map.
     */
    identityProviderName: pulumi.Input<string>;
    /**
     * A JSON-formatted list of user claims and the principal tags that you want to associate with them. When Amazon Cognito requests credentials, it sets the value of the principal tag to the value of the user's claim.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Cognito::IdentityPoolPrincipalTag` for more information about the expected schema for this property.
     */
    principalTags?: any;
    /**
     * Use a default set of mappings between claims and tags for this provider, instead of a custom map.
     */
    useDefaults?: pulumi.Input<boolean>;
}
