import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Connect::ApprovedOrigin
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const approvedOrigin = new aws_native.connect.ApprovedOrigin("approvedOrigin", {
 *     instanceId: "arn:aws:connect:region-name:aws-account-id:instance/instance-arn",
 *     origin: "https://aws.amazon.com",
 * });
 *
 * ```
 */
export declare class ApprovedOrigin extends pulumi.CustomResource {
    /**
     * Get an existing ApprovedOrigin resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ApprovedOrigin;
    /**
     * Returns true if the given object is an instance of ApprovedOrigin.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApprovedOrigin;
    /**
     * The Amazon Resource Name (ARN) of the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `100`
     */
    readonly instanceId: pulumi.Output<string>;
    /**
     * Domain name to be added to the allow-list of the instance.
     *
     * *Maximum* : `267`
     */
    readonly origin: pulumi.Output<string>;
    /**
     * Create a ApprovedOrigin resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApprovedOriginArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ApprovedOrigin resource.
 */
export interface ApprovedOriginArgs {
    /**
     * The Amazon Resource Name (ARN) of the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `100`
     */
    instanceId: pulumi.Input<string>;
    /**
     * Domain name to be added to the allow-list of the instance.
     *
     * *Maximum* : `267`
     */
    origin: pulumi.Input<string>;
}
