import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::View
 */
export declare function getView(args: GetViewArgs, opts?: pulumi.InvokeOptions): Promise<GetViewResult>;
export interface GetViewArgs {
    /**
     * The Amazon Resource Name (ARN) of the view.
     */
    viewArn: string;
}
export interface GetViewResult {
    /**
     * The actions of the view in an array.
     */
    readonly actions?: string[];
    /**
     * The description of the view.
     */
    readonly description?: string;
    /**
     * The Amazon Resource Name (ARN) of the instance.
     */
    readonly instanceArn?: string;
    /**
     * The name of the view.
     */
    readonly name?: string;
    /**
     * One or more tags.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The template of the view as JSON.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Connect::View` for more information about the expected schema for this property.
     */
    readonly template?: any;
    /**
     * The Amazon Resource Name (ARN) of the view.
     */
    readonly viewArn?: string;
    /**
     * The view content hash.
     */
    readonly viewContentSha256?: string;
    /**
     * The view id of the view.
     */
    readonly viewId?: string;
}
/**
 * Resource Type definition for AWS::Connect::View
 */
export declare function getViewOutput(args: GetViewOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetViewResult>;
export interface GetViewOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the view.
     */
    viewArn: pulumi.Input<string>;
}
