import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::LocationEFS.
 */
export declare function getLocationEfs(args: GetLocationEfsArgs, opts?: pulumi.InvokeOptions): Promise<GetLocationEfsResult>;
export interface GetLocationEfsArgs {
    /**
     * The Amazon Resource Name (ARN) of the Amazon EFS file system location that is created.
     */
    locationArn: string;
}
export interface GetLocationEfsResult {
    /**
     * The Amazon Resource Name (ARN) for the Amazon EFS Access point that DataSync uses when accessing the EFS file system.
     */
    readonly accessPointArn?: string;
    /**
     * The Amazon Resource Name (ARN) of the AWS IAM role that the DataSync will assume when mounting the EFS file system.
     */
    readonly fileSystemAccessRoleArn?: string;
    /**
     * Protocol that is used for encrypting the traffic exchanged between the DataSync Agent and the EFS file system.
     */
    readonly inTransitEncryption?: enums.datasync.LocationEfsInTransitEncryption;
    /**
     * The Amazon Resource Name (ARN) of the Amazon EFS file system location that is created.
     */
    readonly locationArn?: string;
    /**
     * The URL of the EFS location that was described.
     */
    readonly locationUri?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::DataSync::LocationEFS.
 */
export declare function getLocationEfsOutput(args: GetLocationEfsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLocationEfsResult>;
export interface GetLocationEfsOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the Amazon EFS file system location that is created.
     */
    locationArn: pulumi.Input<string>;
}
