import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::VerifiedAccessGroup resource creates an AWS EC2 Verified Access Group.
 */
export declare function getVerifiedAccessGroup(args: GetVerifiedAccessGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetVerifiedAccessGroupResult>;
export interface GetVerifiedAccessGroupArgs {
    /**
     * The ID of the AWS Verified Access group.
     */
    verifiedAccessGroupId: string;
}
export interface GetVerifiedAccessGroupResult {
    /**
     * Time this Verified Access Group was created.
     */
    readonly creationTime?: string;
    /**
     * A description for the AWS Verified Access group.
     */
    readonly description?: string;
    /**
     * Time this Verified Access Group was last updated.
     */
    readonly lastUpdatedTime?: string;
    /**
     * The AWS account number that owns the group.
     */
    readonly owner?: string;
    /**
     * The AWS Verified Access policy document.
     */
    readonly policyDocument?: string;
    /**
     * The status of the Verified Access policy.
     */
    readonly policyEnabled?: boolean;
    /**
     * The configuration options for customer provided KMS encryption.
     */
    readonly sseSpecification?: outputs.ec2.VerifiedAccessGroupSseSpecification;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ARN of the Verified Access group.
     */
    readonly verifiedAccessGroupArn?: string;
    /**
     * The ID of the AWS Verified Access group.
     */
    readonly verifiedAccessGroupId?: string;
    /**
     * The ID of the AWS Verified Access instance.
     */
    readonly verifiedAccessInstanceId?: string;
}
/**
 * The AWS::EC2::VerifiedAccessGroup resource creates an AWS EC2 Verified Access Group.
 */
export declare function getVerifiedAccessGroupOutput(args: GetVerifiedAccessGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVerifiedAccessGroupResult>;
export interface GetVerifiedAccessGroupOutputArgs {
    /**
     * The ID of the AWS Verified Access group.
     */
    verifiedAccessGroupId: pulumi.Input<string>;
}
