import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for Local Gateway Route which describes a route for a local gateway route table.
 */
export declare class LocalGatewayRoute extends pulumi.CustomResource {
    /**
     * Get an existing LocalGatewayRoute resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocalGatewayRoute;
    /**
     * Returns true if the given object is an instance of LocalGatewayRoute.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocalGatewayRoute;
    /**
     * The CIDR block used for destination matches.
     */
    readonly destinationCidrBlock: pulumi.Output<string | undefined>;
    /**
     * The ID of the local gateway route table.
     */
    readonly localGatewayRouteTableId: pulumi.Output<string | undefined>;
    /**
     * The ID of the virtual interface group.
     */
    readonly localGatewayVirtualInterfaceGroupId: pulumi.Output<string | undefined>;
    /**
     * The ID of the network interface.
     */
    readonly networkInterfaceId: pulumi.Output<string | undefined>;
    /**
     * The state of the route.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The route type.
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a LocalGatewayRoute resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: LocalGatewayRouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocalGatewayRoute resource.
 */
export interface LocalGatewayRouteArgs {
    /**
     * The CIDR block used for destination matches.
     */
    destinationCidrBlock?: pulumi.Input<string>;
    /**
     * The ID of the local gateway route table.
     */
    localGatewayRouteTableId?: pulumi.Input<string>;
    /**
     * The ID of the virtual interface group.
     */
    localGatewayVirtualInterfaceGroupId?: pulumi.Input<string>;
    /**
     * The ID of the network interface.
     */
    networkInterfaceId?: pulumi.Input<string>;
}
