import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::TransitGatewayConnect type
 */
export declare class TransitGatewayConnect extends pulumi.CustomResource {
    /**
     * Get an existing TransitGatewayConnect resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TransitGatewayConnect;
    /**
     * Returns true if the given object is an instance of TransitGatewayConnect.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TransitGatewayConnect;
    /**
     * The creation time.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The Connect attachment options.
     */
    readonly options: pulumi.Output<outputs.ec2.TransitGatewayConnectOptions>;
    /**
     * The state of the attachment.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The tags for the attachment.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the Connect attachment.
     */
    readonly transitGatewayAttachmentId: pulumi.Output<string>;
    /**
     * The ID of the transit gateway.
     */
    readonly transitGatewayId: pulumi.Output<string>;
    /**
     * The ID of the attachment from which the Connect attachment was created.
     */
    readonly transportTransitGatewayAttachmentId: pulumi.Output<string>;
    /**
     * Create a TransitGatewayConnect resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TransitGatewayConnectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TransitGatewayConnect resource.
 */
export interface TransitGatewayConnectArgs {
    /**
     * The Connect attachment options.
     */
    options: pulumi.Input<inputs.ec2.TransitGatewayConnectOptionsArgs>;
    /**
     * The tags for the attachment.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the attachment from which the Connect attachment was created.
     */
    transportTransitGatewayAttachmentId: pulumi.Input<string>;
}
