import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::EC2::VPCBlockPublicAccessExclusion.
 */
export declare class VpcBlockPublicAccessExclusion extends pulumi.CustomResource {
    /**
     * Get an existing VpcBlockPublicAccessExclusion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcBlockPublicAccessExclusion;
    /**
     * Returns true if the given object is an instance of VpcBlockPublicAccessExclusion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcBlockPublicAccessExclusion;
    /**
     * The ID of the exclusion
     */
    readonly exclusionId: pulumi.Output<string>;
    /**
     * The desired Block Public Access Exclusion Mode for a specific VPC/Subnet.
     */
    readonly internetGatewayExclusionMode: pulumi.Output<enums.ec2.VpcBlockPublicAccessExclusionInternetGatewayExclusionMode>;
    /**
     * The ID of the subnet. Required only if you don't specify VpcId
     */
    readonly subnetId: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the vpc. Required only if you don't specify SubnetId.
     */
    readonly vpcId: pulumi.Output<string | undefined>;
    /**
     * Create a VpcBlockPublicAccessExclusion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcBlockPublicAccessExclusionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcBlockPublicAccessExclusion resource.
 */
export interface VpcBlockPublicAccessExclusionArgs {
    /**
     * The desired Block Public Access Exclusion Mode for a specific VPC/Subnet.
     */
    internetGatewayExclusionMode: pulumi.Input<enums.ec2.VpcBlockPublicAccessExclusionInternetGatewayExclusionMode>;
    /**
     * The ID of the subnet. Required only if you don't specify VpcId
     */
    subnetId?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the vpc. Required only if you don't specify SubnetId.
     */
    vpcId?: pulumi.Input<string>;
}
