import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An object representing an Amazon EKS PodIdentityAssociation.
 */
export declare class PodIdentityAssociation extends pulumi.CustomResource {
    /**
     * Get an existing PodIdentityAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PodIdentityAssociation;
    /**
     * Returns true if the given object is an instance of PodIdentityAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PodIdentityAssociation;
    /**
     * The ARN of the pod identity association.
     */
    readonly associationArn: pulumi.Output<string>;
    /**
     * The ID of the pod identity association.
     */
    readonly associationId: pulumi.Output<string>;
    /**
     * The cluster that the pod identity association is created for.
     */
    readonly clusterName: pulumi.Output<string>;
    /**
     * The Disable Session Tags of the pod identity association.
     */
    readonly disableSessionTags: pulumi.Output<boolean | undefined>;
    /**
     * The External Id of the pod identity association.
     */
    readonly externalId: pulumi.Output<string>;
    /**
     * The Kubernetes namespace that the pod identity association is created for.
     */
    readonly namespace: pulumi.Output<string>;
    /**
     * The IAM role ARN that the pod identity association is created for.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The Kubernetes service account that the pod identity association is created for.
     */
    readonly serviceAccount: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Target Role Arn of the pod identity association.
     */
    readonly targetRoleArn: pulumi.Output<string | undefined>;
    /**
     * Create a PodIdentityAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PodIdentityAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PodIdentityAssociation resource.
 */
export interface PodIdentityAssociationArgs {
    /**
     * The cluster that the pod identity association is created for.
     */
    clusterName: pulumi.Input<string>;
    /**
     * The Disable Session Tags of the pod identity association.
     */
    disableSessionTags?: pulumi.Input<boolean>;
    /**
     * The Kubernetes namespace that the pod identity association is created for.
     */
    namespace: pulumi.Input<string>;
    /**
     * The IAM role ARN that the pod identity association is created for.
     */
    roleArn: pulumi.Input<string>;
    /**
     * The Kubernetes service account that the pod identity association is created for.
     */
    serviceAccount: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The Target Role Arn of the pod identity association.
     */
    targetRoleArn?: pulumi.Input<string>;
}
