import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * MatchingWorkflow defined in AWS Entity Resolution service
 */
export declare function getMatchingWorkflow(args: GetMatchingWorkflowArgs, opts?: pulumi.InvokeOptions): Promise<GetMatchingWorkflowResult>;
export interface GetMatchingWorkflowArgs {
    /**
     * The name of the MatchingWorkflow
     */
    workflowName: string;
}
export interface GetMatchingWorkflowResult {
    readonly createdAt?: string;
    /**
     * The description of the MatchingWorkflow
     */
    readonly description?: string;
    /**
     * An object which defines an incremental run type and has only `incrementalRunType` as a field.
     */
    readonly incrementalRunConfig?: outputs.entityresolution.MatchingWorkflowIncrementalRunConfig;
    /**
     * A list of `InputSource` objects, which have the fields `InputSourceARN` and `SchemaName` .
     */
    readonly inputSourceConfig?: outputs.entityresolution.MatchingWorkflowInputSource[];
    /**
     * A list of `OutputSource` objects, each of which contains fields `OutputS3Path` , `ApplyNormalization` , and `Output` .
     */
    readonly outputSourceConfig?: outputs.entityresolution.MatchingWorkflowOutputSource[];
    /**
     * An object which defines the `resolutionType` and the `ruleBasedProperties` .
     */
    readonly resolutionTechniques?: outputs.entityresolution.MatchingWorkflowResolutionTechniques;
    /**
     * The Amazon Resource Name (ARN) of the IAM role. AWS Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
     */
    readonly roleArn?: string;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags?: outputs.Tag[];
    readonly updatedAt?: string;
    readonly workflowArn?: string;
}
/**
 * MatchingWorkflow defined in AWS Entity Resolution service
 */
export declare function getMatchingWorkflowOutput(args: GetMatchingWorkflowOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMatchingWorkflowResult>;
export interface GetMatchingWorkflowOutputArgs {
    /**
     * The name of the MatchingWorkflow
     */
    workflowName: pulumi.Input<string>;
}
