import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * An environment created within the EVS service
 */
export declare class Environment extends pulumi.CustomResource {
    /**
     * Get an existing Environment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Environment;
    /**
     * Returns true if the given object is an instance of Environment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Environment;
    readonly checks: pulumi.Output<outputs.evs.EnvironmentCheck[]>;
    readonly connectivityInfo: pulumi.Output<outputs.evs.ConnectivityInfoProperties>;
    readonly createdAt: pulumi.Output<string>;
    readonly credentials: pulumi.Output<outputs.evs.EnvironmentSecret[]>;
    readonly environmentArn: pulumi.Output<string>;
    readonly environmentId: pulumi.Output<string>;
    /**
     * The name of an EVS environment
     */
    readonly environmentName: pulumi.Output<string | undefined>;
    readonly environmentState: pulumi.Output<enums.evs.EnvironmentState>;
    /**
     * The initial hosts for environment only required upon creation. Modification after creation will have no effect
     */
    readonly hosts: pulumi.Output<outputs.evs.EnvironmentHostInfoForCreate[] | undefined>;
    /**
     * The initial Vlan configuration only required upon creation. Modification after creation will have no effect
     */
    readonly initialVlans: pulumi.Output<outputs.evs.InitialVlansProperties | undefined>;
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    /**
     * The license information for an EVS environment
     */
    readonly licenseInfo: pulumi.Output<outputs.evs.LicenseInfoProperties>;
    readonly modifiedAt: pulumi.Output<string>;
    readonly serviceAccessSecurityGroups: pulumi.Output<outputs.evs.ServiceAccessSecurityGroupsProperties | undefined>;
    readonly serviceAccessSubnetId: pulumi.Output<string>;
    readonly siteId: pulumi.Output<string>;
    readonly stateDetails: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    readonly termsAccepted: pulumi.Output<boolean>;
    readonly vcfHostnames: pulumi.Output<outputs.evs.VcfHostnamesProperties>;
    readonly vcfVersion: pulumi.Output<enums.evs.EnvironmentVcfVersion>;
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a Environment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EnvironmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Environment resource.
 */
export interface EnvironmentArgs {
    connectivityInfo: pulumi.Input<inputs.evs.ConnectivityInfoPropertiesArgs>;
    /**
     * The name of an EVS environment
     */
    environmentName?: pulumi.Input<string>;
    /**
     * The initial hosts for environment only required upon creation. Modification after creation will have no effect
     */
    hosts?: pulumi.Input<pulumi.Input<inputs.evs.EnvironmentHostInfoForCreateArgs>[]>;
    /**
     * The initial Vlan configuration only required upon creation. Modification after creation will have no effect
     */
    initialVlans?: pulumi.Input<inputs.evs.InitialVlansPropertiesArgs>;
    kmsKeyId?: pulumi.Input<string>;
    /**
     * The license information for an EVS environment
     */
    licenseInfo: pulumi.Input<inputs.evs.LicenseInfoPropertiesArgs>;
    serviceAccessSecurityGroups?: pulumi.Input<inputs.evs.ServiceAccessSecurityGroupsPropertiesArgs>;
    serviceAccessSubnetId: pulumi.Input<string>;
    siteId: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    termsAccepted: pulumi.Input<boolean>;
    vcfHostnames: pulumi.Input<inputs.evs.VcfHostnamesPropertiesArgs>;
    vcfVersion: pulumi.Input<enums.evs.EnvironmentVcfVersion>;
    vpcId: pulumi.Input<string>;
}
