import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS Ground Station config resource type for CloudFormation.
 */
export declare class Config extends pulumi.CustomResource {
    /**
     * Get an existing Config resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Config;
    /**
     * Returns true if the given object is an instance of Config.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Config;
    /**
     * The ARN of the config, such as `arn:aws:groundstation:us-east-2:1234567890:config/tracking/9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the config, such as `9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Object containing the parameters of a config. Only one subtype may be specified per config. See the subtype definitions for a description of each config subtype.
     */
    readonly configData: pulumi.Output<outputs.groundstation.ConfigData>;
    /**
     * The name of the config object.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Tags assigned to a resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of the config, such as `tracking` .
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a Config resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConfigArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Config resource.
 */
export interface ConfigArgs {
    /**
     * Object containing the parameters of a config. Only one subtype may be specified per config. See the subtype definitions for a description of each config subtype.
     */
    configData: pulumi.Input<inputs.groundstation.ConfigDataArgs>;
    /**
     * The name of the config object.
     */
    name?: pulumi.Input<string>;
    /**
     * Tags assigned to a resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
