import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An invoice unit is a set of mutually exclusive accounts that correspond to your business entity. Invoice units allow you to separate AWS account costs and configures your invoice for each business entity.
 */
export declare class InvoiceUnit extends pulumi.CustomResource {
    /**
     * Get an existing InvoiceUnit resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): InvoiceUnit;
    /**
     * Returns true if the given object is an instance of InvoiceUnit.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is InvoiceUnit;
    /**
     * The assigned description for an invoice unit. This information can't be modified or deleted.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The account that receives invoices related to the invoice unit.
     */
    readonly invoiceReceiver: pulumi.Output<string>;
    /**
     * The ARN to identify an invoice unit. This information can't be modified or deleted.
     */
    readonly invoiceUnitArn: pulumi.Output<string>;
    /**
     * The last time the invoice unit was updated. This is important to determine the version of invoice unit configuration used to create the invoices. Any invoice created after this modified time will use this invoice unit configuration.
     */
    readonly lastModified: pulumi.Output<number>;
    /**
     * A unique name that is distinctive within your AWS .
     */
    readonly name: pulumi.Output<string>;
    /**
     * The tag structure that contains a tag key and value.
     */
    readonly resourceTags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * An `InvoiceUnitRule` object used the categorize invoice units.
     */
    readonly rule: pulumi.Output<outputs.invoicing.InvoiceUnitRule>;
    /**
     * Whether the invoice unit based tax inheritance is/ should be enabled or disabled.
     */
    readonly taxInheritanceDisabled: pulumi.Output<boolean | undefined>;
    /**
     * Create a InvoiceUnit resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: InvoiceUnitArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a InvoiceUnit resource.
 */
export interface InvoiceUnitArgs {
    /**
     * The assigned description for an invoice unit. This information can't be modified or deleted.
     */
    description?: pulumi.Input<string>;
    /**
     * The account that receives invoices related to the invoice unit.
     */
    invoiceReceiver: pulumi.Input<string>;
    /**
     * A unique name that is distinctive within your AWS .
     */
    name?: pulumi.Input<string>;
    /**
     * The tag structure that contains a tag key and value.
     */
    resourceTags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * An `InvoiceUnitRule` object used the categorize invoice units.
     */
    rule: pulumi.Input<inputs.invoicing.InvoiceUnitRuleArgs>;
    /**
     * Whether the invoice unit based tax inheritance is/ should be enabled or disabled.
     */
    taxInheritanceDisabled?: pulumi.Input<boolean>;
}
