import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Scheduled audits can be used to specify the checks you want to perform during an audit and how often the audit should be run.
 */
export declare function getScheduledAudit(args: GetScheduledAuditArgs, opts?: pulumi.InvokeOptions): Promise<GetScheduledAuditResult>;
export interface GetScheduledAuditArgs {
    /**
     * The name you want to give to the scheduled audit.
     */
    scheduledAuditName: string;
}
export interface GetScheduledAuditResult {
    /**
     * The day of the month on which the scheduled audit takes place. Can be 1 through 31 or LAST. This field is required if the frequency parameter is set to MONTHLY.
     */
    readonly dayOfMonth?: string;
    /**
     * The day of the week on which the scheduled audit takes place. Can be one of SUN, MON, TUE,WED, THU, FRI, or SAT. This field is required if the frequency parameter is set to WEEKLY or BIWEEKLY.
     */
    readonly dayOfWeek?: enums.iot.ScheduledAuditDayOfWeek;
    /**
     * How often the scheduled audit takes place. Can be one of DAILY, WEEKLY, BIWEEKLY, or MONTHLY.
     */
    readonly frequency?: enums.iot.ScheduledAuditFrequency;
    /**
     * The ARN (Amazon resource name) of the scheduled audit.
     */
    readonly scheduledAuditArn?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Which checks are performed during the scheduled audit. Checks must be enabled for your account.
     */
    readonly targetCheckNames?: string[];
}
/**
 * Scheduled audits can be used to specify the checks you want to perform during an audit and how often the audit should be run.
 */
export declare function getScheduledAuditOutput(args: GetScheduledAuditOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetScheduledAuditResult>;
export interface GetScheduledAuditOutputArgs {
    /**
     * The name you want to give to the scheduled audit.
     */
    scheduledAuditName: pulumi.Input<string>;
}
