import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::IoT::TopicRuleDestination
 */
export declare class TopicRuleDestination extends pulumi.CustomResource {
    /**
     * Get an existing TopicRuleDestination resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TopicRuleDestination;
    /**
     * Returns true if the given object is an instance of TopicRuleDestination.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TopicRuleDestination;
    /**
     * Amazon Resource Name (ARN).
     */
    readonly arn: pulumi.Output<string>;
    /**
     * HTTP URL destination properties.
     */
    readonly httpUrlProperties: pulumi.Output<outputs.iot.TopicRuleDestinationHttpUrlDestinationSummary | undefined>;
    /**
     * The status of the TopicRuleDestination.
     */
    readonly status: pulumi.Output<enums.iot.TopicRuleDestinationStatus | undefined>;
    /**
     * The reasoning for the current status of the TopicRuleDestination.
     */
    readonly statusReason: pulumi.Output<string>;
    /**
     * VPC destination properties.
     */
    readonly vpcProperties: pulumi.Output<outputs.iot.TopicRuleDestinationVpcDestinationProperties | undefined>;
    /**
     * Create a TopicRuleDestination resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TopicRuleDestinationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TopicRuleDestination resource.
 */
export interface TopicRuleDestinationArgs {
    /**
     * HTTP URL destination properties.
     */
    httpUrlProperties?: pulumi.Input<inputs.iot.TopicRuleDestinationHttpUrlDestinationSummaryArgs>;
    /**
     * The status of the TopicRuleDestination.
     */
    status?: pulumi.Input<enums.iot.TopicRuleDestinationStatus>;
    /**
     * VPC destination properties.
     */
    vpcProperties?: pulumi.Input<inputs.iot.TopicRuleDestinationVpcDestinationPropertiesArgs>;
}
