import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource type definition for AWS::NetworkFirewall::LoggingConfiguration
 */
export declare class LoggingConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing LoggingConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LoggingConfiguration;
    /**
     * Returns true if the given object is an instance of LoggingConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LoggingConfiguration;
    readonly enableMonitoringDashboard: pulumi.Output<boolean | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the `Firewall` that the logging configuration is associated with. You can't change the firewall specification after you create the logging configuration.
     */
    readonly firewallArn: pulumi.Output<string>;
    /**
     * The name of the firewall that the logging configuration is associated with. You can't change the firewall specification after you create the logging configuration.
     */
    readonly firewallName: pulumi.Output<string | undefined>;
    /**
     * Defines how AWS Network Firewall performs logging for a `Firewall` .
     */
    readonly loggingConfiguration: pulumi.Output<outputs.networkfirewall.LoggingConfiguration>;
    /**
     * Create a LoggingConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LoggingConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LoggingConfiguration resource.
 */
export interface LoggingConfigurationArgs {
    enableMonitoringDashboard?: pulumi.Input<boolean>;
    /**
     * The Amazon Resource Name (ARN) of the `Firewall` that the logging configuration is associated with. You can't change the firewall specification after you create the logging configuration.
     */
    firewallArn: pulumi.Input<string>;
    /**
     * The name of the firewall that the logging configuration is associated with. You can't change the firewall specification after you create the logging configuration.
     */
    firewallName?: pulumi.Input<string>;
    /**
     * Defines how AWS Network Firewall performs logging for a `Firewall` .
     */
    loggingConfiguration: pulumi.Input<inputs.networkfirewall.LoggingConfigurationArgs>;
}
