import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::NetworkManager::Device type describes a device.
 */
export declare class Device extends pulumi.CustomResource {
    /**
     * Get an existing Device resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Device;
    /**
     * Returns true if the given object is an instance of Device.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Device;
    /**
     * The Amazon Web Services location of the device, if applicable.
     */
    readonly awsLocation: pulumi.Output<outputs.networkmanager.DeviceAwsLocation | undefined>;
    /**
     * The date and time that the device was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the device.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the device.
     */
    readonly deviceArn: pulumi.Output<string>;
    /**
     * The ID of the device.
     */
    readonly deviceId: pulumi.Output<string>;
    /**
     * The ID of the global network.
     */
    readonly globalNetworkId: pulumi.Output<string>;
    /**
     * The site location.
     */
    readonly location: pulumi.Output<outputs.networkmanager.DeviceLocation | undefined>;
    /**
     * The device model
     */
    readonly model: pulumi.Output<string | undefined>;
    /**
     * The device serial number.
     */
    readonly serialNumber: pulumi.Output<string | undefined>;
    /**
     * The site ID.
     */
    readonly siteId: pulumi.Output<string | undefined>;
    /**
     * The state of the device.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The tags for the device.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The device type.
     */
    readonly type: pulumi.Output<string | undefined>;
    /**
     * The device vendor.
     */
    readonly vendor: pulumi.Output<string | undefined>;
    /**
     * Create a Device resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DeviceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Device resource.
 */
export interface DeviceArgs {
    /**
     * The Amazon Web Services location of the device, if applicable.
     */
    awsLocation?: pulumi.Input<inputs.networkmanager.DeviceAwsLocationArgs>;
    /**
     * The description of the device.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the global network.
     */
    globalNetworkId: pulumi.Input<string>;
    /**
     * The site location.
     */
    location?: pulumi.Input<inputs.networkmanager.DeviceLocationArgs>;
    /**
     * The device model
     */
    model?: pulumi.Input<string>;
    /**
     * The device serial number.
     */
    serialNumber?: pulumi.Input<string>;
    /**
     * The site ID.
     */
    siteId?: pulumi.Input<string>;
    /**
     * The tags for the device.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The device type.
     */
    type?: pulumi.Input<string>;
    /**
     * The device vendor.
     */
    vendor?: pulumi.Input<string>;
}
