import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Amazon OpenSearchService application resource
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * List of application configurations.
     */
    readonly appConfigs: pulumi.Output<outputs.opensearchservice.ApplicationAppConfig[] | undefined>;
    /**
     * Amazon Resource Name (ARN) format.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The identifier of the application.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * List of data sources.
     */
    readonly dataSources: pulumi.Output<outputs.opensearchservice.ApplicationDataSource[] | undefined>;
    /**
     * The endpoint for the application.
     */
    readonly endpoint: pulumi.Output<string | undefined>;
    /**
     * Options for configuring IAM Identity Center
     */
    readonly iamIdentityCenterOptions: pulumi.Output<outputs.opensearchservice.IamIdentityCenterOptionsProperties | undefined>;
    /**
     * The name of the application.
     */
    readonly name: pulumi.Output<string>;
    /**
     * An arbitrary set of tags (key-value pairs) for this application.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * List of application configurations.
     */
    appConfigs?: pulumi.Input<pulumi.Input<inputs.opensearchservice.ApplicationAppConfigArgs>[]>;
    /**
     * List of data sources.
     */
    dataSources?: pulumi.Input<pulumi.Input<inputs.opensearchservice.ApplicationDataSourceArgs>[]>;
    /**
     * The endpoint for the application.
     */
    endpoint?: pulumi.Input<string>;
    /**
     * Options for configuring IAM Identity Center
     */
    iamIdentityCenterOptions?: pulumi.Input<inputs.opensearchservice.IamIdentityCenterOptionsPropertiesArgs>;
    /**
     * The name of the application.
     */
    name?: pulumi.Input<string>;
    /**
     * An arbitrary set of tags (key-value pairs) for this application.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
