import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::RDS::DBClusterParameterGroup`` resource creates a new Amazon RDS DB cluster parameter group.
 *  For information about configuring parameters for Amazon Aurora DB clusters, see [Working with parameter groups](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_WorkingWithParamGroups.html) in the *Amazon Aurora User Guide*.
 *   If you apply a parameter group to a DB cluster, then its DB instances might need to reboot. This can result in an outage while the DB instances are rebooting.
 *  If you apply a change to parameter group associated with a stopped DB cluster, then the updated stack waits until the DB cluster is started.
 */
export declare function getDbClusterParameterGroup(args: GetDbClusterParameterGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetDbClusterParameterGroupResult>;
export interface GetDbClusterParameterGroupArgs {
    /**
     * The name of the DB cluster parameter group.
     *  Constraints:
     *   +  Must not match the name of an existing DB cluster parameter group.
     *
     *   This value is stored as a lowercase string.
     */
    dbClusterParameterGroupName: string;
}
export interface GetDbClusterParameterGroupResult {
    /**
     * Provides a list of parameters for the DB cluster parameter group.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::RDS::DBClusterParameterGroup` for more information about the expected schema for this property.
     */
    readonly parameters?: any;
    /**
     * Tags to assign to the DB cluster parameter group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The ``AWS::RDS::DBClusterParameterGroup`` resource creates a new Amazon RDS DB cluster parameter group.
 *  For information about configuring parameters for Amazon Aurora DB clusters, see [Working with parameter groups](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_WorkingWithParamGroups.html) in the *Amazon Aurora User Guide*.
 *   If you apply a parameter group to a DB cluster, then its DB instances might need to reboot. This can result in an outage while the DB instances are rebooting.
 *  If you apply a change to parameter group associated with a stopped DB cluster, then the updated stack waits until the DB cluster is started.
 */
export declare function getDbClusterParameterGroupOutput(args: GetDbClusterParameterGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDbClusterParameterGroupResult>;
export interface GetDbClusterParameterGroupOutputArgs {
    /**
     * The name of the DB cluster parameter group.
     *  Constraints:
     *   +  Must not match the name of an existing DB cluster parameter group.
     *
     *   This value is stored as a lowercase string.
     */
    dbClusterParameterGroupName: pulumi.Input<string>;
}
