import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::RolesAnywhere::Profile Resource Type
 */
export declare class Profile extends pulumi.CustomResource {
    /**
     * Get an existing Profile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Profile;
    /**
     * Returns true if the given object is an instance of Profile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Profile;
    /**
     * Used to determine if a custom role session name will be accepted in a temporary credential request.
     */
    readonly acceptRoleSessionName: pulumi.Output<boolean | undefined>;
    /**
     * A mapping applied to the authenticating end-entity certificate.
     */
    readonly attributeMappings: pulumi.Output<outputs.rolesanywhere.ProfileAttributeMapping[] | undefined>;
    /**
     * The number of seconds vended session credentials will be valid for
     */
    readonly durationSeconds: pulumi.Output<number | undefined>;
    /**
     * The enabled status of the resource.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * A list of managed policy ARNs. Managed policies identified by this list will be applied to the vended session credentials.
     */
    readonly managedPolicyArns: pulumi.Output<string[] | undefined>;
    /**
     * The customer specified name of the resource.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ARN of the profile.
     */
    readonly profileArn: pulumi.Output<string>;
    /**
     * The unique primary identifier of the Profile
     */
    readonly profileId: pulumi.Output<string>;
    /**
     * Specifies whether instance properties are required in CreateSession requests with this profile.
     */
    readonly requireInstanceProperties: pulumi.Output<boolean | undefined>;
    /**
     * A list of IAM role ARNs that can be assumed when this profile is specified in a CreateSession request.
     */
    readonly roleArns: pulumi.Output<string[]>;
    /**
     * A session policy that will applied to the trust boundary of the vended session credentials.
     */
    readonly sessionPolicy: pulumi.Output<string | undefined>;
    /**
     * A list of Tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Profile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Profile resource.
 */
export interface ProfileArgs {
    /**
     * Used to determine if a custom role session name will be accepted in a temporary credential request.
     */
    acceptRoleSessionName?: pulumi.Input<boolean>;
    /**
     * A mapping applied to the authenticating end-entity certificate.
     */
    attributeMappings?: pulumi.Input<pulumi.Input<inputs.rolesanywhere.ProfileAttributeMappingArgs>[]>;
    /**
     * The number of seconds vended session credentials will be valid for
     */
    durationSeconds?: pulumi.Input<number>;
    /**
     * The enabled status of the resource.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * A list of managed policy ARNs. Managed policies identified by this list will be applied to the vended session credentials.
     */
    managedPolicyArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The customer specified name of the resource.
     */
    name?: pulumi.Input<string>;
    /**
     * Specifies whether instance properties are required in CreateSession requests with this profile.
     */
    requireInstanceProperties?: pulumi.Input<boolean>;
    /**
     * A list of IAM role ARNs that can be assumed when this profile is specified in a CreateSession request.
     */
    roleArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A session policy that will applied to the trust boundary of the vended session credentials.
     */
    sessionPolicy?: pulumi.Input<string>;
    /**
     * A list of Tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
