import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::ModelCard.
 */
export declare function getModelCard(args: GetModelCardArgs, opts?: pulumi.InvokeOptions): Promise<GetModelCardResult>;
export interface GetModelCardArgs {
    /**
     * The unique name of the model card.
     */
    modelCardName: string;
}
export interface GetModelCardResult {
    /**
     * The content of the model card. Content uses the [model card JSON schema](https://docs.aws.amazon.com/sagemaker/latest/dg/model-cards.html#model-cards-json-schema) .
     */
    readonly content?: outputs.sagemaker.ModelCardContent;
    /**
     * Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
     */
    readonly createdBy?: outputs.sagemaker.ModelCardUserContext;
    /**
     * The date and time the model card was created.
     */
    readonly creationTime?: string;
    /**
     * Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
     */
    readonly lastModifiedBy?: outputs.sagemaker.ModelCardUserContext;
    /**
     * The date and time the model card was last modified.
     */
    readonly lastModifiedTime?: string;
    /**
     * The Amazon Resource Name (ARN) of the successfully created model card.
     */
    readonly modelCardArn?: string;
    /**
     * The processing status of model card deletion. The ModelCardProcessingStatus updates throughout the different deletion steps.
     */
    readonly modelCardProcessingStatus?: enums.sagemaker.ModelCardProcessingStatus;
    /**
     * The approval status of the model card within your organization. Different organizations might have different criteria for model card review and approval.
     */
    readonly modelCardStatus?: enums.sagemaker.ModelCardStatus;
    /**
     * A version of the model card.
     */
    readonly modelCardVersion?: number;
    /**
     * Key-value pairs used to manage metadata for model cards.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::SageMaker::ModelCard.
 */
export declare function getModelCardOutput(args: GetModelCardOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetModelCardResult>;
export interface GetModelCardOutputArgs {
    /**
     * The unique name of the model card.
     */
    modelCardName: pulumi.Input<string>;
}
