import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::ModelPackageGroup
 */
export declare function getModelPackageGroup(args: GetModelPackageGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetModelPackageGroupResult>;
export interface GetModelPackageGroupArgs {
    /**
     * The Amazon Resource Name (ARN) of the model group.
     */
    modelPackageGroupArn: string;
}
export interface GetModelPackageGroupResult {
    /**
     * The time at which the model package group was created.
     */
    readonly creationTime?: string;
    /**
     * The Amazon Resource Name (ARN) of the model group.
     */
    readonly modelPackageGroupArn?: string;
    /**
     * A resouce policy to control access to a model group. For information about resoure policies, see [Identity-based policies and resource-based policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_identity-vs-resource.html) in the *AWS Identity and Access Management User Guide.* .
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SageMaker::ModelPackageGroup` for more information about the expected schema for this property.
     */
    readonly modelPackageGroupPolicy?: any;
    /**
     * The status of a modelpackage group job.
     */
    readonly modelPackageGroupStatus?: enums.sagemaker.ModelPackageGroupStatus;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::SageMaker::ModelPackageGroup
 */
export declare function getModelPackageGroupOutput(args: GetModelPackageGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetModelPackageGroupResult>;
export interface GetModelPackageGroupOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the model group.
     */
    modelPackageGroupArn: pulumi.Input<string>;
}
