import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Scheduler::Schedule Resource Type
 */
export declare function getSchedule(args: GetScheduleArgs, opts?: pulumi.InvokeOptions): Promise<GetScheduleResult>;
export interface GetScheduleArgs {
    /**
     * The name of the schedule.
     */
    name: string;
}
export interface GetScheduleResult {
    /**
     * The Amazon Resource Name (ARN) of the schedule.
     */
    readonly arn?: string;
    /**
     * The description of the schedule.
     */
    readonly description?: string;
    /**
     * The date, in UTC, before which the schedule can invoke its target. Depending on the schedule's recurrence expression, invocations might stop on, or before, the EndDate you specify.
     */
    readonly endDate?: string;
    /**
     * Allows you to configure a time window during which EventBridge Scheduler invokes the schedule.
     */
    readonly flexibleTimeWindow?: outputs.scheduler.ScheduleFlexibleTimeWindow;
    /**
     * The name of the schedule group to associate with this schedule. If you omit this, the default schedule group is used.
     */
    readonly groupName?: string;
    /**
     * The ARN for a KMS Key that will be used to encrypt customer data.
     */
    readonly kmsKeyArn?: string;
    /**
     * The scheduling expression.
     */
    readonly scheduleExpression?: string;
    /**
     * The timezone in which the scheduling expression is evaluated.
     */
    readonly scheduleExpressionTimezone?: string;
    /**
     * The date, in UTC, after which the schedule can begin invoking its target. Depending on the schedule's recurrence expression, invocations might occur on, or after, the StartDate you specify.
     */
    readonly startDate?: string;
    /**
     * Specifies whether the schedule is enabled or disabled.
     *
     * *Allowed Values* : `ENABLED` | `DISABLED`
     */
    readonly state?: enums.scheduler.ScheduleState;
    /**
     * The schedule's target details.
     */
    readonly target?: outputs.scheduler.ScheduleTarget;
}
/**
 * Definition of AWS::Scheduler::Schedule Resource Type
 */
export declare function getScheduleOutput(args: GetScheduleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetScheduleResult>;
export interface GetScheduleOutputArgs {
    /**
     * The name of the schedule.
     */
    name: pulumi.Input<string>;
}
