import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Schema for AWS::ServiceCatalogAppRegistry::AttributeGroup.
 */
export declare class AttributeGroup extends pulumi.CustomResource {
    /**
     * Get an existing AttributeGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AttributeGroup;
    /**
     * Returns true if the given object is an instance of AttributeGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AttributeGroup;
    /**
     * The Amazon resource name (ARN) that specifies the attribute group across services.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A nested object in a JSON or YAML template that supports arbitrary definitions. Represents the attributes in an attribute group that describes an application and its components.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ServiceCatalogAppRegistry::AttributeGroup` for more information about the expected schema for this property.
     */
    readonly attributes: pulumi.Output<any>;
    /**
     * The globally unique attribute group identifier of the attribute group.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The description of the attribute group.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the attribute group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Key-value pairs you can use to associate with the attribute group.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a AttributeGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AttributeGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AttributeGroup resource.
 */
export interface AttributeGroupArgs {
    /**
     * A nested object in a JSON or YAML template that supports arbitrary definitions. Represents the attributes in an attribute group that describes an application and its components.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ServiceCatalogAppRegistry::AttributeGroup` for more information about the expected schema for this property.
     */
    attributes: any;
    /**
     * The description of the attribute group.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the attribute group.
     */
    name?: pulumi.Input<string>;
    /**
     * Key-value pairs you can use to associate with the attribute group.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
