import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::SES::MailManagerTrafficPolicy Resource Type
 */
export declare function getMailManagerTrafficPolicy(args: GetMailManagerTrafficPolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetMailManagerTrafficPolicyResult>;
export interface GetMailManagerTrafficPolicyArgs {
    /**
     * The identifier of the traffic policy resource.
     */
    trafficPolicyId: string;
}
export interface GetMailManagerTrafficPolicyResult {
    /**
     * Default action instructs the traﬃc policy to either Allow or Deny (block) messages that fall outside of (or not addressed by) the conditions of your policy statements
     */
    readonly defaultAction?: enums.ses.MailManagerTrafficPolicyAcceptAction;
    /**
     * The maximum message size in bytes of email which is allowed in by this traffic policy—anything larger will be blocked.
     */
    readonly maxMessageSizeBytes?: number;
    /**
     * Conditional statements for filtering email traffic.
     */
    readonly policyStatements?: outputs.ses.MailManagerTrafficPolicyPolicyStatement[];
    /**
     * The tags used to organize, track, or control access for the resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The Amazon Resource Name (ARN) of the traffic policy resource.
     */
    readonly trafficPolicyArn?: string;
    /**
     * The identifier of the traffic policy resource.
     */
    readonly trafficPolicyId?: string;
    /**
     * The name of the policy.
     *
     * The policy name cannot exceed 64 characters and can only include alphanumeric characters, dashes, and underscores.
     */
    readonly trafficPolicyName?: string;
}
/**
 * Definition of AWS::SES::MailManagerTrafficPolicy Resource Type
 */
export declare function getMailManagerTrafficPolicyOutput(args: GetMailManagerTrafficPolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMailManagerTrafficPolicyResult>;
export interface GetMailManagerTrafficPolicyOutputArgs {
    /**
     * The identifier of the traffic policy resource.
     */
    trafficPolicyId: pulumi.Input<string>;
}
