import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Contains a list of Regular expressions based on the provided inputs. RegexPatternSet can be used with other WAF entities with RegexPatternSetReferenceStatement to perform other actions .
 */
export declare class RegexPatternSet extends pulumi.CustomResource {
    /**
     * Get an existing RegexPatternSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RegexPatternSet;
    /**
     * Returns true if the given object is an instance of RegexPatternSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RegexPatternSet;
    /**
     * ARN of the WAF entity.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Id of the RegexPatternSet
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Description of the entity.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Name of the RegexPatternSet.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The regular expression patterns in the set.
     */
    readonly regularExpressionList: pulumi.Output<string[]>;
    /**
     * Use CLOUDFRONT for CloudFront RegexPatternSet, use REGIONAL for Application Load Balancer and API Gateway.
     */
    readonly scope: pulumi.Output<enums.wafv2.RegexPatternSetScope>;
    /**
     * Key:value pairs associated with an AWS resource. The key:value pair can be anything you define. Typically, the tag key represents a category (such as "environment") and the tag value represents a specific value within that category (such as "test," "development," or "production"). You can add up to 50 tags to each AWS resource.
     *
     * > To modify tags on existing resources, use the AWS WAF APIs or command line interface. With AWS CloudFormation , you can only add tags to AWS WAF resources during resource creation.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a RegexPatternSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RegexPatternSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RegexPatternSet resource.
 */
export interface RegexPatternSetArgs {
    /**
     * Description of the entity.
     */
    description?: pulumi.Input<string>;
    /**
     * Name of the RegexPatternSet.
     */
    name?: pulumi.Input<string>;
    /**
     * The regular expression patterns in the set.
     */
    regularExpressionList: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Use CLOUDFRONT for CloudFront RegexPatternSet, use REGIONAL for Application Load Balancer and API Gateway.
     */
    scope: pulumi.Input<enums.wafv2.RegexPatternSetScope>;
    /**
     * Key:value pairs associated with an AWS resource. The key:value pair can be anything you define. Typically, the tag key represents a category (such as "environment") and the tag value represents a specific value within that category (such as "test," "development," or "production"). You can add up to 50 tags to each AWS resource.
     *
     * > To modify tags on existing resources, use the AWS WAF APIs or command line interface. With AWS CloudFormation , you can only add tags to AWS WAF resources during resource creation.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
