import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Wisdom::MessageTemplate Resource Type
 */
export declare function getMessageTemplate(args: GetMessageTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetMessageTemplateResult>;
export interface GetMessageTemplateArgs {
    /**
     * The Amazon Resource Name (ARN) of the message template.
     */
    messageTemplateArn: string;
}
export interface GetMessageTemplateResult {
    /**
     * The content of the message template.
     */
    readonly content?: outputs.wisdom.MessageTemplateContent;
    /**
     * An object that specifies the default values to use for variables in the message template. This object contains different categories of key-value pairs. Each key defines a variable or placeholder in the message template. The corresponding value defines the default value for that variable.
     */
    readonly defaultAttributes?: outputs.wisdom.MessageTemplateAttributes;
    /**
     * The description of the message template.
     */
    readonly description?: string;
    /**
     * The configuration information of the external data source.
     */
    readonly groupingConfiguration?: outputs.wisdom.MessageTemplateGroupingConfiguration;
    /**
     * The language code value for the language in which the message template is written. The supported language codes include de_DE, en_US, es_ES, fr_FR, id_ID, it_IT, ja_JP, ko_KR, pt_BR, zh_CN, zh_TW
     */
    readonly language?: string;
    /**
     * The Amazon Resource Name (ARN) of the message template.
     */
    readonly messageTemplateArn?: string;
    /**
     * The content SHA256 of the message template.
     */
    readonly messageTemplateContentSha256?: string;
    /**
     * The unique identifier of the message template.
     */
    readonly messageTemplateId?: string;
    /**
     * The name of the message template.
     */
    readonly name?: string;
    /**
     * The tags used to organize, track, or control access for this resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Definition of AWS::Wisdom::MessageTemplate Resource Type
 */
export declare function getMessageTemplateOutput(args: GetMessageTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMessageTemplateResult>;
export interface GetMessageTemplateOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the message template.
     */
    messageTemplateArn: pulumi.Input<string>;
}
